@@ -1,4 +1,5 @@
 //! Error handling for the Breezy Python bindings
+use crate::transform::RawConflict;
 use pyo3::import_exception;
 use pyo3::prelude::*;
 use pyo3::PyErr;
@@ -6,6 +7,7 @@ use url::Url;
 
 import_exception!(breezy.errors, UnknownFormatError);
 import_exception!(breezy.errors, NotBranchError);
+import_exception!(breezy.errors, ReadOnlyError);
 import_exception!(breezy.controldir, NoColocatedBranchSupport);
 import_exception!(breezy.errors, DependencyNotPresent);
 import_exception!(breezy.errors, PermissionDenied);
@@ -55,6 +57,8 @@ import_exception!(breezy.forge, SourceNotDerivedFromTarget);
 import_exception!(breezy.controldir, BranchReferenceLoop);
 import_exception!(breezy.errors, RedirectRequested);
 import_exception!(breezy.errors, ConflictsInTree);
+import_exception!(breezy.errors, NoRoundtrippingSupport);
+import_exception!(breezy.inter, NoCompatibleInter);
 
 lazy_static::lazy_static! {
     // Only present in breezy << 4.0
@@ -114,7 +118,7 @@ pub enum Error {
     MissingNestedTree(std::path::PathBuf),
     /// Failed to delete transform temporary directory
     ImmortalLimbo(std::path::PathBuf),
-    MalformedTransform(String),
+    MalformedTransform(Vec<RawConflict>),
     TransformRenameFailed(
         std::path::PathBuf,
         std::path::PathBuf,
@@ -144,6 +148,9 @@ pub enum Error {
         is_permanent: bool,
     },
     ConflictsInTree,
+    NoRoundtrippingSupport,
+    NoCompatibleInter,
+    ReadOnly,
 }
 
 impl From<url::ParseError> for Error {
@@ -249,7 +256,7 @@ impl std::fmt::Display for Error {
                 "Failed to delete transform temporary directory: {}",
                 p.display()
             ),
-            Self::MalformedTransform(e) => write!(f, "Malformed transform: {}", e),
+            Self::MalformedTransform(e) => write!(f, "Malformed transform: {:?}", e),
             Self::TransformRenameFailed(a, b, c, d) => write!(
                 f,
                 "Transform rename failed: {} -> {}: {}: {}",
@@ -286,6 +293,9 @@ impl std::fmt::Display for Error {
             Self::ConflictsInTree => write!(f, "Conflicts in tree"),
             Self::SourceNotDerivedFromTarget => write!(f, "Source not derived from target"),
             Self::BranchReferenceLoop => write!(f, "Branch reference loop"),
+            Self::NoRoundtrippingSupport => write!(f, "No roundtripping support"),
+            Self::NoCompatibleInter => write!(f, "No compatible inter"),
+            Self::ReadOnly => write!(f, "Read-only"),
             Self::RedirectRequested {
                 source,
                 target,
@@ -569,6 +579,8 @@ impl From<PyErr> for Error {
                 .unwrap_or(false)
             {
                 Error::ConnectionError(err.to_string())
+            } else if err.is_instance_of::<ReadOnlyError>(py) {
+                Error::ReadOnly
             } else if err.is_instance_of::<RedirectRequested>(py) {
                 Error::RedirectRequested {
                     source: value
@@ -587,6 +599,10 @@ impl From<PyErr> for Error {
                         .unwrap(),
                     is_permanent: value.getattr("is_permanent").unwrap().extract().unwrap(),
                 }
+            } else if err.is_instance_of::<NoRoundtrippingSupport>(py) {
+                Error::NoRoundtrippingSupport
+            } else if err.is_instance_of::<NoCompatibleInter>(py) {
+                Error::NoCompatibleInter
             // Intentionally sorted below the more specific errors
             } else if err.is_instance_of::<InvalidHttpResponse>(py) {
                 Error::InvalidHttpResponse(
@@ -600,6 +616,10 @@ impl From<PyErr> for Error {
             } else if err.is_instance_of::<BranchReferenceLoop>(py) {
                 Error::BranchReferenceLoop
             } else {
+                if std::env::var("BRZ_ERROR").is_ok() {
+                    // Print backtrace
+                    err.print(py);
+                }
                 Self::Other(err)
             }
         })
@@ -686,7 +706,9 @@ impl From<Error> for PyErr {
                 MissingNestedTree::new_err((p.to_string_lossy().to_string(),))
             }
             Error::ImmortalLimbo(p) => ImmortalLimbo::new_err((p.to_string_lossy().to_string(),)),
-            Error::MalformedTransform(conflicts) => MalformedTransform::new_err((conflicts,)),
+            Error::MalformedTransform(conflicts) => {
+                MalformedTransform::new_err((Python::with_gil(|py| conflicts.to_object(py)),))
+            }
             Error::TransformRenameFailed(from_path, to_path, why, error) => {
                 TransformRenameFailed::new_err((
                     from_path.to_string_lossy().to_string(),
@@ -717,11 +739,18 @@ impl From<Error> for PyErr {
             Error::ConflictsInTree => ConflictsInTree::new_err(()),
             Error::SourceNotDerivedFromTarget => SourceNotDerivedFromTarget::new_err(()),
             Error::BranchReferenceLoop => BranchReferenceLoop::new_err(()),
+            Error::ReadOnly => Python::with_gil(|py| ReadOnlyError::new_err((py.None(),))),
             Error::RedirectRequested {
                 source,
                 target,
                 is_permanent,
             } => RedirectRequested::new_err((source.to_string(), target.to_string(), is_permanent)),
+            Error::NoRoundtrippingSupport => {
+                Python::with_gil(|py| NoRoundtrippingSupport::new_err((py.None(), py.None())))
+            }
+            Error::NoCompatibleInter => {
+                Python::with_gil(|py| NoCompatibleInter::new_err((py.None(), py.None())))
+            }
         }
     }
 }
@@ -1130,7 +1159,8 @@ fn test_immortal_limbo() {
 
 #[test]
 fn test_malformed_transform() {
-    let e = Error::MalformedTransform("foo".to_string());
+    let e = Error::MalformedTransform(vec![]);
+
     let p: PyErr = e.into();
     // Verify that p is an instance of MalformedTransform
     Python::with_gil(|py| {
