@@ -8,9 +8,14 @@ use pyo3::prelude::*;
 use pyo3::types::PyDict;
 use std::hash::Hash;
 
-#[derive(Clone)]
 pub struct Forge(PyObject);
 
+impl Clone for Forge {
+    fn clone(&self) -> Self {
+        Forge(Python::with_gil(|py| self.0.clone_ref(py)))
+    }
+}
+
 impl From<PyObject> for Forge {
     fn from(obj: PyObject) -> Self {
         Forge(obj)
@@ -96,9 +101,14 @@ impl FromPyObject<'_> for MergeProposalStatus {
     }
 }
 
-#[derive(Clone)]
 pub struct MergeProposal(PyObject);
 
+impl Clone for MergeProposal {
+    fn clone(&self) -> Self {
+        MergeProposal(Python::with_gil(|py| self.0.clone_ref(py)))
+    }
+}
+
 impl From<PyObject> for MergeProposal {
     fn from(obj: PyObject) -> Self {
         MergeProposal(obj)
@@ -267,7 +277,7 @@ impl MergeProposal {
 }
 
 #[pyclass]
-pub struct ProposalBuilder(PyObject, PyObject);
+pub struct ProposalBuilder(PyObject, Py<PyDict>);
 
 impl ProposalBuilder {
     pub fn description(self, description: &str) -> Self {
@@ -324,7 +334,9 @@ impl ProposalBuilder {
     pub fn build(self) -> Result<MergeProposal, crate::error::Error> {
         Python::with_gil(|py| {
             let kwargs = self.1;
-            let proposal = self.0.call_method1(py, "create_proposal", (kwargs,))?;
+            let proposal =
+                self.0
+                    .call_method_bound(py, "create_proposal", (), Some(kwargs.bind(py)))?;
             Ok(MergeProposal::from(proposal))
         })
     }
@@ -530,26 +542,26 @@ impl Forge {
     pub fn publish_derived(
         &self,
         local_branch: &dyn Branch,
-        main_branch: &dyn Branch,
+        base_branch: &dyn Branch,
         name: &str,
-        overwrite_existing: Option<bool>,
+        overwrite: Option<bool>,
         owner: Option<&str>,
-        stop_revision: Option<&RevisionId>,
+        revision_id: Option<&RevisionId>,
         tag_selector: Option<Box<dyn Fn(String) -> bool>>,
     ) -> Result<(Box<dyn Branch>, url::Url), crate::error::Error> {
         Python::with_gil(|py| {
             let kwargs = PyDict::new_bound(py);
             kwargs.set_item("local_branch", local_branch.to_object(py))?;
-            kwargs.set_item("main_branch", main_branch.to_object(py))?;
+            kwargs.set_item("base_branch", base_branch.to_object(py))?;
             kwargs.set_item("name", name)?;
-            if let Some(overwrite_existing) = overwrite_existing {
-                kwargs.set_item("overwrite_existing", overwrite_existing)?;
+            if let Some(overwrite) = overwrite {
+                kwargs.set_item("overwrite", overwrite)?;
             }
             if let Some(owner) = owner {
                 kwargs.set_item("owner", owner)?;
             }
-            if let Some(stop_revision) = stop_revision {
-                kwargs.set_item("stop_revision", stop_revision)?;
+            if let Some(revision_id) = revision_id {
+                kwargs.set_item("revision_id", revision_id)?;
             }
             if let Some(tag_selector) = tag_selector {
                 kwargs.set_item("tag_selector", py_tag_selector(py, tag_selector)?)?;
@@ -647,13 +659,18 @@ pub fn get_forge_by_hostname(hostname: &str) -> Result<Forge, Error> {
     })
 }
 
-pub fn determine_title(description: &str) -> String {
+pub fn determine_title(description: &str) -> Result<String, String> {
     Python::with_gil(|py| {
         let m = py.import_bound("breezy.forge").unwrap();
-        let title = m.call_method1("determine_title", (description,)).unwrap();
-        title.extract::<String>()
+        let title = match m.call_method1("determine_title", (description,)) {
+            Ok(title) => title,
+            Err(e) => return Err(e.to_string()),
+        };
+        match title.extract::<String>() {
+            Ok(title) => Ok(title),
+            Err(e) => Err(e.to_string()),
+        }
     })
-    .unwrap()
 }
 
 pub fn iter_forge_instances() -> impl Iterator<Item = Forge> {
@@ -685,3 +702,22 @@ pub fn get_proposal_by_url(url: &url::Url) -> Result<MergeProposal, Error> {
         Ok(MergeProposal::from(proposal.to_object(py)))
     })
 }
+
+#[cfg(test)]
+mod tests {
+    #[test]
+    fn test_determine_title() {
+        let description = "This is a test description";
+        let title = super::determine_title(description).unwrap();
+        assert_eq!(title, "This is a test description");
+    }
+
+    #[test]
+    fn test_determine_title_invalid() {
+        let description = "";
+        assert_eq!(
+            "ValueError: ",
+            super::determine_title(description).unwrap_err()
+        );
+    }
+}
