@@ -3,8 +3,10 @@
 //! A repository is a collection of revisions and their associated data.
 use crate::controldir::ControlDir;
 use crate::delta::TreeDelta;
+use crate::foreign::VcsType;
 use crate::graph::Graph;
 use crate::location::AsLocation;
+use crate::lock::Lock;
 use crate::revisionid::RevisionId;
 use crate::tree::RevisionTree;
 use chrono::DateTime;
@@ -133,6 +135,16 @@ impl Repository {
         Repository(obj)
     }
 
+    pub fn vcs_type(&self) -> VcsType {
+        Python::with_gil(|py| {
+            if self.to_object(py).getattr(py, "_git").is_ok() {
+                VcsType::Git
+            } else {
+                VcsType::Bazaar
+            }
+        })
+    }
+
     pub fn get_user_url(&self) -> url::Url {
         Python::with_gil(|py| {
             self.0
@@ -145,6 +157,18 @@ impl Repository {
         })
     }
 
+    pub fn user_transport(&self) -> crate::transport::Transport {
+        Python::with_gil(|py| {
+            crate::transport::Transport::new(self.0.getattr(py, "user_transport").unwrap())
+        })
+    }
+
+    pub fn control_transport(&self) -> crate::transport::Transport {
+        Python::with_gil(|py| {
+            crate::transport::Transport::new(self.0.getattr(py, "control_transport").unwrap())
+        })
+    }
+
     pub fn fetch(
         &self,
         other_repository: &Repository,
@@ -234,6 +258,34 @@ impl Repository {
         .map_err(|e| e.into())
         .map(|(v, _m)| (v,))
     }
+
+    pub fn lookup_foreign_revision_id(
+        &self,
+        foreign_revid: &[u8],
+    ) -> Result<RevisionId, crate::error::Error> {
+        Python::with_gil(|py| {
+            self.0
+                .call_method1(py, "lookup_foreign_revision_id", (foreign_revid,))?
+                .extract(py)
+        })
+        .map_err(|e| e.into())
+    }
+
+    pub fn lock_read(&self) -> Result<Lock, crate::error::Error> {
+        Python::with_gil(|py| {
+            Ok(Lock::from(
+                self.to_object(py).call_method0(py, "lock_read")?,
+            ))
+        })
+    }
+
+    pub fn lock_write(&self) -> Result<Lock, crate::error::Error> {
+        Python::with_gil(|py| {
+            Ok(Lock::from(
+                self.to_object(py).call_method0(py, "lock_write")?,
+            ))
+        })
+    }
 }
 
 pub fn open(base: impl AsLocation) -> Result<Repository, crate::error::Error> {
