@@ -1,5 +1,5 @@
 //! Working trees
-use crate::branch::{Branch, RegularBranch};
+use crate::branch::{Branch, GenericBranch};
 use crate::controldir::ControlDir;
 use crate::error::Error;
 use crate::tree::{MutableTree, RevisionTree, Tree};
@@ -113,7 +113,7 @@ impl WorkingTree {
     pub fn branch(&self) -> Box<dyn Branch> {
         Python::with_gil(|py| {
             let branch = self.to_object(py).getattr(py, "branch").unwrap();
-            Box::new(RegularBranch::new(branch)) as Box<dyn Branch>
+            Box::new(GenericBranch::new(branch)) as Box<dyn Branch>
         })
     }
 
@@ -275,12 +275,64 @@ impl WorkingTree {
         .map(|_| ())
     }
 
-    pub fn safe_relpath_files(&self, file_list: &[&Path], canonicalize: bool, apply_view: bool) -> Result<Vec<PathBuf>, Error> {
+    pub fn merge_from_branch(
+        &self,
+        source: &dyn Branch,
+        to_revision: Option<&RevisionId>,
+    ) -> Result<(), Error> {
+        Python::with_gil(|py| {
+            let kwargs = {
+                let kwargs = pyo3::types::PyDict::new_bound(py);
+                if let Some(to_revision) = to_revision {
+                    kwargs
+                        .set_item("to_revision", to_revision.to_object(py))
+                        .unwrap();
+                }
+                kwargs
+            };
+            self.to_object(py).call_method_bound(
+                py,
+                "merge_from_branch",
+                (source.to_object(py),),
+                Some(&kwargs),
+            )
+        })
+        .map_err(|e| e.into())
+        .map(|_| ())
+    }
+
+    pub fn update(&self, revision: Option<&RevisionId>) -> Result<(), Error> {
+        Python::with_gil(|py| {
+            let kwargs = {
+                let kwargs = pyo3::types::PyDict::new_bound(py);
+                kwargs.set_item("revision", revision.to_object(py)).unwrap();
+                kwargs
+            };
+            self.to_object(py)
+                .call_method_bound(py, "update", (), Some(&kwargs))
+        })
+        .map_err(|e| e.into())
+        .map(|_| ())
+    }
+
+    pub fn safe_relpath_files(
+        &self,
+        file_list: &[&Path],
+        canonicalize: bool,
+        apply_view: bool,
+    ) -> Result<Vec<PathBuf>, Error> {
         Python::with_gil(|py| {
             let result = self.to_object(py).call_method1(
                 py,
                 "safe_relpath_files",
-                (file_list.iter().map(|x| x.to_path_buf()).collect::<Vec<_>>(), canonicalize, apply_view),
+                (
+                    file_list
+                        .iter()
+                        .map(|x| x.to_path_buf())
+                        .collect::<Vec<_>>(),
+                    canonicalize,
+                    apply_view,
+                ),
             )?;
             Ok(result.extract(py)?)
         })
